@@ -83,6 +83,9 @@ std::string ToStringGenerator(SpvReflectGenerator generator) {
     case SPV_REFLECT_GENERATOR_CLAY_CLAY_SHADER_COMPILER:
       return "Clay Clay Shader Compiler";
       break;
+    case SPV_REFLECT_GENERATOR_SLANG_SHADER_COMPILER:
+      return "Slang Shader Compiler";
+      break;
   }
   // unhandled SpvReflectGenerator enum value
   return "???";
@@ -108,6 +111,14 @@ std::string ToStringSpvSourceLanguage(SpvSourceLanguage lang) {
       return "Hero C";
     case SpvSourceLanguageNZSL:
       return "NZSL";
+    case SpvSourceLanguageWGSL:
+      return "WGSL";
+    case SpvSourceLanguageSlang:
+      return "Slang";
+    case SpvSourceLanguageZig:
+      return "Zig";
+    case SpvSourceLanguageRust:
+      return "Rust";
 
     default:
       break;
@@ -793,6 +804,8 @@ std::string ToStringDecorationFlags(SpvReflectDecorationFlags decoration_flags)
   PRINT_AND_CLEAR_DECORATION_FLAG(sstream, decoration_flags, PATCH);
   PRINT_AND_CLEAR_DECORATION_FLAG(sstream, decoration_flags, PER_VERTEX);
   PRINT_AND_CLEAR_DECORATION_FLAG(sstream, decoration_flags, PER_TASK);
+  PRINT_AND_CLEAR_DECORATION_FLAG(sstream, decoration_flags, WEIGHT_TEXTURE);
+  PRINT_AND_CLEAR_DECORATION_FLAG(sstream, decoration_flags, BLOCK_MATCH_TEXTURE);
 #undef PRINT_AND_CLEAR_DECORATION_FLAG
   if (decoration_flags != 0) {
     // Unhandled SpvReflectDecorationFlags bit
